#include "dialog.h"
#include "ui_dialog.h"
#include <QFileDialog>
#include <QMessageBox>
#include <QAxObject>
#include <sstream>
#include <fstream>

using namespace std;

Dialog::Dialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Dialog)
{
    ui->setupUi(this);
}

Dialog::~Dialog()
{
    delete ui;
}

void Dialog::on_b_einlesen_clicked()
{
    // Erst einmal die zu öffnende Datei erfragen...
    auto filename = QFileDialog::getOpenFileName(this, "", "", "");
    if(filename.length() == 0) return;

    // In jeder Zeile stehen vier Koordinaten: x1, y1, x2, y2
    // Diese werden eingelesen und im Vektor "data" gespeichert.
    Line my_line;
    data.clear();
    ifstream strm(filename.toStdString());
    while(strm >> my_line.x1 >> my_line.y1 >> my_line.x2 >> my_line.y2)
    {
        data.push_back(my_line);
    }

    // Message-Box zur Kontrolle...
    ostringstream txt;
    txt << data.size() << " Linien eingelesen.";

    QMessageBox msg;
    msg.setText(txt.str().c_str());
    msg.exec();
}

void Dialog::on_b_uebertragen_clicked()
{
    QAxObject catia;
    catia.setControl("CATIA.Application");
    if(catia.isNull()) { MsgBox("Verbindungsaufbau fehlgeschlagen!"); return; }

    QAxObject *activeDoc = catia.querySubObject("ActiveDocument");
    if(!activeDoc) { MsgBox("Fehler: Kein Dokument geöffnet?"); return; }

    QAxObject *part = activeDoc->querySubObject("Part");
    if(!part) { MsgBox("Fehler: Kein Part geöffnet?"); return; }

    QAxObject *hybShapeFac = part->querySubObject("HybridShapeFactory");
    QAxObject *hBodies = part->querySubObject("HybridBodies");
    QAxObject *hBody_1 = hBodies->querySubObject("Add(void)");

    for(auto l : data)
    {
        QVariant point_a = hybShapeFac->dynamicCall("AddNewPointCoord(double,double,double)", 0, l.x1, l.y1);
        QVariant point_b = hybShapeFac->dynamicCall("AddNewPointCoord(double,double,double)", 0, l.x2, l.y2);
        QAxObject* ref_a = part->querySubObject("CreateReferenceFromObject(QVariant)", point_a);
        QAxObject* ref_b = part->querySubObject("CreateReferenceFromObject(QVariant)", point_b);
        QAxObject* line  = hybShapeFac->querySubObject("AddNewLinePtPt(QAxObject*,QAxObject*)", ref_a->asVariant(), ref_b->asVariant());
        hBody_1->dynamicCall("AppendHybridShape(QAxObject*)", line->asVariant());
    }

    part->dynamicCall("Update(void)");
}

void Dialog::MsgBox(std::string msg)
{
    QMessageBox box;
    box.setText(msg.c_str());
    box.exec();
}
