#include "dialog.h"
#include "ui_dialog.h"
#include <QMessageBox>
#include <fstream>

void Dialog::MsgBox(QString msg)
{
    QMessageBox box;
    box.setText(msg);
    box.exec();
}

Dialog::Dialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Dialog)
{
    ui->setupUi(this);
    setWindowFlags(windowFlags()^Qt::WindowContextHelpButtonHint);
}

Dialog::~Dialog()
{
    delete ui;
}

void Dialog::on_b_erzeugen_clicked()
{
    double anzahl  = ui->t_anzahl ->text().toDouble();
    if(anzahl < 1) { MsgBox("Bitte gültige Anzahl eingeben!"); return; }

    double abstand = ui->t_abstand->text().toDouble();
    if(abstand <= 0) { MsgBox("Bitte gültigen Abstand eingeben!"); return; }

    catia.setControl("CATIA.Application");
    if(catia.isNull()) { MsgBox("Verbindungsaufbau fehlgeschlagen!"); return; }

    QAxObject *activeDoc = catia.querySubObject("ActiveDocument");
    if(!activeDoc) { MsgBox("Fehler: Kein Dokument geöffnet?"); return; }

    QAxObject *part = activeDoc->querySubObject("Part");
    if(!part) { MsgBox("Fehler: Kein Part geöffnet?"); return; }

    QAxObject *hybShapeFac = part->querySubObject("HybridShapeFactory");
    QAxObject *hKoerper = part->querySubObject("HybridBodies");
    QAxObject *measurementPoints = hKoerper->querySubObject("Add(void)");

    for(double x = 0; x < anzahl * abstand ; x += abstand)
    {
        for(double y = 0; y < anzahl * abstand ; y += abstand)
        {
            QVariant point = hybShapeFac->dynamicCall("AddNewPointCoord(double,double,double)", x, y, 0.0);
            measurementPoints->dynamicCall("AppendHybridShape(QVariant)", point);
        }
    }
    part->dynamicCall("Update(void)");
}
